@@ -115,7 +115,7 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
 /* Readline */
-/* #undef HAVE_HIST_ENTRY */
+#define HAVE_HIST_ENTRY 1
 /* #undef USE_LIBEDIT_INTERFACE */
 #define USE_NEW_READLINE_INTERFACE 1
 
@@ -532,16 +532,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 11
-#define MYSQL_VERSION_PATCH 10
+#define MYSQL_VERSION_PATCH 11
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.11.10"
+#define PACKAGE_STRING "MySQL Server 10.11.11"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.11.10"
-#define VERSION "10.11.10"
+#define PACKAGE_VERSION "10.11.11"
+#define VERSION "10.11.11"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
